Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Result ¶
Result: the results of running a command against a specific host. The struct and its fields are exported to enable live-streaming results to the caller.
type WorkerPool ¶
type WorkerPool struct {
// contains filtered or unexported fields
}
WorkerPool: everything required to orchestrate running the command against remote hosts
func CreatePool ¶
func CreatePool(poolSize int, cmd string, config ssh.ClientConfig) *WorkerPool
CreatePool: create the worker pool
func (*WorkerPool) RunJob ¶
RunJob: run the remote command against the specified host and return the Result. Return an error if the context is cancelled before the job finishes.
func (*WorkerPool) ScheduleWorkers ¶
func (wp *WorkerPool) ScheduleWorkers()
ScheduleWorkers: add workers to the worker pool
Click to show internal directories.
Click to hide internal directories.